curl https://raw.githubusercontent.com/unicode-org/cldr/main/common/supplemental/windowsZones.xml > win_cldr_data/windowsZones.xml
cd tz && git checkout main && git pull && cd ..
